
package com.abssqr.plat.biz.api.plan;

import com.abssqr.plat.biz.support.ServiceSupport;
import com.abssqr.plat.common.dal.mysql.auto.paging.AstPackPagePage;
import com.abssqr.plat.common.dal.mysql.auto.paging.PlanListPage;
import com.abssqr.plat.common.facade.base.BaseStringParam;
import com.abssqr.plat.common.facade.enums.PlanStatusEnum;
import com.abssqr.plat.common.facade.model.plan.Plan;
import com.abssqr.plat.common.facade.param.plan.PlanEditOprParam;
import com.abssqr.plat.common.facade.param.plan.PlanPageQryParam;
import com.abssqr.plat.common.facade.result.BasePage;
import com.abssqr.plat.common.facade.result.pack.AstPackListVO;
import com.abssqr.plat.common.facade.result.plan.PlanVO;
import com.abssqr.plat.common.facade.service.plan.PlanService;
import com.abssqr.plat.common.facade.validation.Valid;
import com.abssqr.plat.common.model.convertor.vo.AstPackListVOConvert;
import com.abssqr.plat.common.model.convertor.web.PlanWebConvert;
import com.abssqr.plat.common.model.repo.plan.PlanRepo;
import com.abssqr.plat.core.service.plan.PlanMananger;
import com.general.system.common.model.BaseResult;
import com.general.system.common.util.VarChecker;
import com.general.system.facade.current.IdentityUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

@Component
public class PlanServiceImpl extends ServiceSupport implements PlanService{

    @Autowired
    PlanMananger planMananger;

    @Autowired
    PlanRepo planRepo;

    /**
     * 增改产品
     * @param planEditOprParam
     * @return
     */
    @Override
    public String edit(@Valid PlanEditOprParam planEditOprParam) {
        return doOpr(planEditOprParam, () -> {
            return planMananger.addOrUpdatePlan(planEditOprParam, IdentityUtil.getUserCode());
        });
    }

    /**
     * 获取产品详情
     * @param planNo
     * @return
     */
    @Override
    public PlanVO get(String planNo) {
        return super.doQry(new BaseStringParam(planNo),()->{
            Plan plan = planMananger.getPlan(planNo);
           return PlanWebConvert.convert2PlanVO(plan);
        });
    }

    /**
     * 分页获取产品列表
     * @param planPageQryParam
     * @return
     */
    @Override
    public BasePage<PlanVO> page(PlanPageQryParam planPageQryParam) {
        return super.doQry(planPageQryParam,()->{
            PlanListPage planList = planRepo.getPlanList(PlanWebConvert.convertParam2Page(planPageQryParam));
            return PlanWebConvert.convertPage2VO(planList);
        });
    }

    @Override
    public BaseResult<Boolean> delete(String planNo) {
        Plan plan = planRepo.getPlanByNo(planNo);
        VarChecker.checkNotNull(plan,"产品[{0}]不存在",planNo);
        VarChecker.checkArgument(plan.getStatus()== PlanStatusEnum.DRAFT||plan.getStatus()==PlanStatusEnum.PREPARING,"产品状态为[{0}]不饿能删除",plan.getStatus().getDesc());
        planRepo.deletePlan(planNo);
        return BaseResult.success(true);
    }

}


