package com.abssqr.plat.common.dal.mysql.auto.dao;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Repository;
import java.util.ArrayList;
import com.abssqr.plat.common.dal.mysql.auto.dataobject.PlanDO;
import java.util.List;
import com.abssqr.plat.common.dal.mysql.auto.paging.PlanListPage;
import com.abssqr.plat.common.dal.mysql.auto.mapper.PlanDOMapper;

/**
* The Table abs_plan.
* 产品表
*/
@Repository
public class PlanDAO{

    @Autowired
    private PlanDOMapper planDOMapper;

    /**
     * desc:插入表:abs_plan.<br/>
     * @param entity entity
     * @return int
     */
    
    public int insert(PlanDO entity){
        return planDOMapper.insert(entity);
    }
    /**
     * desc:批量插入表:abs_plan.<br/>
     * @param list list
     * @return int
     */
    
    public int insertBatch(List<PlanDO> list){
        planDOMapper.insertBatch(list);
        return  list.size(); 
    }
    /**
     * desc:getPlanByNo.<br/>
     * @param planNo planNo
     * @return PlanDO
     */
    
    public PlanDO getPlanByNo(String planNo){
        return planDOMapper.getPlanByNo(planNo);
    }
    /**
     * desc:根据唯一约束PlanNo更新表:abs_plan.<br/>
     * @param entity entity
     * @return int
     */
    
    public int updatePlanByNo(PlanDO entity){
        return planDOMapper.updatePlanByNo(entity);
    }
    /**
     * desc:根据PlanName 和 PlanFullName判断是否存在对应的计划.<br/>
     * @param planName planName
     * @param planFullName planFullName
     * @return int
     */
    
    public int planExist(String planName,String planFullName){
        return planDOMapper.planExist(planName, planFullName);
    }
    /**
     * desc:getPlanList.<br/>
     * @param planList planList
     * @return PlanListPage
     */
    
    public PlanListPage getPlanList(PlanListPage planList){
        int total = planDOMapper.getPlanListCount(planList);
        if(total>0){
            planList.setDatas(planDOMapper.getPlanListResult(planList));
        }else{
            planList.setDatas(new ArrayList());
        }
        planList.setTotal(total);
        return planList;
    }
    /**
     * desc:deleteByPlanNo.<br/>
     * @param planNo planNo
     * @return int
     */
    
    public int deleteByPlanNo(String planNo){
        return planDOMapper.deleteByPlanNo(planNo);
    }
}
