package com.abssqr.plat.common.facade.param.plan;

import com.abssqr.plat.common.facade.base.BaseOprParam;
import com.abssqr.plat.common.facade.enums.CalcIntrTypeEnum;
import com.abssqr.plat.common.facade.enums.EventCodeEnum;
import com.abssqr.plat.common.facade.enums.PlanPayFreqEnum;
import com.abssqr.plat.common.facade.param.plan.sub.FeeStructureParam;
import com.abssqr.plat.common.facade.param.plan.sub.InvestStructureParam;
import com.abssqr.plat.common.facade.validation.*;

import javax.validation.constraints.NotNull;
import java.util.Date;
import java.util.List;

public class PlanEditOprParam extends BaseOprParam {

    /**
     * 计划编号
     */
    private String planNo;
    /**
     * totalAmt 发行规模.
     */
    @VldRange(max = 10000000,min = 0)
    private Long totalAmt;
    /**
     * planName 产品简称.
     */
    @VldNotNull
    private String planName;
    /**
     * tradePlace 交易场所.
     */
    @VldNotNull
    private String tradePlace;
    /**
     * calcIntrType 计息方式/计息基准.
     */
    @VldEnums(enumClass = CalcIntrTypeEnum.class)
    private String calcIntrType;
    /**
     * planFullName 产品全称.
     */
    @VldString(maxLength = 30,minLength = 0)
    private String planFullName;
    /**
     * payFreq 兑付频率.
     */
    @VldEnums(enumClass = PlanPayFreqEnum.class)
    private String payFreq;
    /**
     * endDate 法定到期日.
     */
    @VldNotNull
    private Date endDate;
    /**
     * beginDate 产品成立日.
     */
    private Date beginDate;

    /**
     * firstPayDate 首次转付日.
     */
    @VldNotNull
    private Date firstPayDate;
    /**
     * firstCalcDate 首次计算日.
     */
    @VldNotNull
    private Date firstCalcDate;
    /**
     * firstAllocDate 首次分配日.
     */
    @VldNotNull
    private Date firstAllocDate;
    /**
     * firstReportDate 首次报告日.
     */
    @VldNotNull
    private Date firstReportDate;
    /**
     * firstSettleDate 首次结息日.
     */
    @VldNotNull
    private Date firstSettleDate;


    //是否是暂存
    private boolean draft;


    //费用结构
    private List<FeeStructureParam> feeStructureParam;

    //投资结构
    private List<InvestStructureParam> investStructureParam;

    public Long getTotalAmt() {
        return totalAmt;
    }

    public void setTotalAmt(Long totalAmt) {
        this.totalAmt = totalAmt;
    }

    public String getPlanName() {
        return planName;
    }

    public void setPlanName(String planName) {
        this.planName = planName;
    }

    public String getTradePlace() {
        return tradePlace;
    }

    public void setTradePlace(String tradePlace) {
        this.tradePlace = tradePlace;
    }

    public String getCalcIntrType() {
        return calcIntrType;
    }

    public void setCalcIntrType(String calcIntrType) {
        this.calcIntrType = calcIntrType;
    }

    public String getPlanFullName() {
        return planFullName;
    }

    public void setPlanFullName(String planFullName) {
        this.planFullName = planFullName;
    }

    public String getPayFreq() {
        return payFreq;
    }

    public void setPayFreq(String payFreq) {
        this.payFreq = payFreq;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }

    public Date getBeginDate() {
        return beginDate;
    }

    public void setBeginDate(Date beginDate) {
        this.beginDate = beginDate;
    }

    public Date getFirstPayDate() {
        return firstPayDate;
    }

    public void setFirstPayDate(Date firstPayDate) {
        this.firstPayDate = firstPayDate;
    }

    public Date getFirstCalcDate() {
        return firstCalcDate;
    }

    public void setFirstCalcDate(Date firstCalcDate) {
        this.firstCalcDate = firstCalcDate;
    }

    public Date getFirstAllocDate() {
        return firstAllocDate;
    }

    public void setFirstAllocDate(Date firstAllocDate) {
        this.firstAllocDate = firstAllocDate;
    }

    public Date getFirstReportDate() {
        return firstReportDate;
    }

    public void setFirstReportDate(Date firstReportDate) {
        this.firstReportDate = firstReportDate;
    }

    public Date getFirstSettleDate() {
        return firstSettleDate;
    }

    public void setFirstSettleDate(Date firstSettleDate) {
        this.firstSettleDate = firstSettleDate;
    }

    public List<FeeStructureParam> getFeeStructureParam() {
        return feeStructureParam;
    }

    public void setFeeStructureParam(List<FeeStructureParam> feeStructureParam) {
        this.feeStructureParam = feeStructureParam;
    }

    public List<InvestStructureParam> getInvestStructureParam() {
        return investStructureParam;
    }

    public void setInvestStructureParam(List<InvestStructureParam> investStructureParam) {
        this.investStructureParam = investStructureParam;
    }

    public boolean isDraft() {
        return draft;
    }

    public void setDraft(boolean draft) {
        this.draft = draft;
    }


    public String getPlanNo() {
        return planNo;
    }

    public void setPlanNo(String planNo) {
        this.planNo = planNo;
    }

    @Override
    public EventCodeEnum getEventCode() {
        return EventCodeEnum.ADMIN_EDIT;
    }
}
