/**
 * abssqr.com Inc.
 * Copyright (c) 2017-2019 All Rights Reserved.
 */
package com.abssqr.plat.common.facade.param.plan.sub;

import com.abssqr.plat.common.facade.enums.CalcTypeEnum;
import com.abssqr.plat.common.facade.enums.FeeScaleTypeEnum;
import com.abssqr.plat.common.facade.enums.FeeTimeTypeEnum;
import com.abssqr.plat.common.facade.enums.FinSerFeeTypeEnum;
import com.abssqr.plat.common.facade.validation.VldEnums;
import com.abssqr.plat.common.facade.validation.VldRange;
import com.abssqr.plat.common.facade.validation.VldString;
import com.general.system.common.model.BaseEntity;

import javax.validation.constraints.Max;
import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 费用结构
 *
 * @author bangis.wangdf
 * @version com.abssqr.plat.common.facade.param.plan.sub: FeeStructureParam.java, v 0.1 2019-05-30 15:06 bangis.wangdf Exp $
 */
public class FeeStructureParam extends BaseEntity implements Serializable {
    private static final long              serialVersionUID = -8054344184679429967L;
    /**
     * order .
     */
    @VldRange(max = 10,min=0)
    private Long sort;
    /**
     * fixedFeeAmt 固定费用.
     */
    @VldRange(max = 15,min=0)
    private Long fixedFeeAmt;
    /**
     * payLimitAmt 支付上限.
     */
    @VldRange(max = 15,min=0)
    private Long payLimitAmt;
    /**
     * feeCalcType 计费方式.
     */
    @VldEnums(enumClass = CalcTypeEnum.class)
    private String feeCalcType;
    /**
     * feeScaleType 费用基准.
     */
    @VldEnums(enumClass = FeeScaleTypeEnum.class)
    private String feeScaleType;

    /**
     * feeCalcDefaultDate 默认计费时间.
     */

    @VldEnums(enumClass = FeeTimeTypeEnum.class)
    private String feeTimeType;
    /**
     * feeRate 费率.
     */
    @VldRange(max = 1,min = 0)
    private String feeRate;


    /**
     * 费用名称
     */
    @VldString(maxLength = 30)
    private String feeName;

    public Long getSort() {
        return sort;
    }

    public void setSort(Long sort) {
        this.sort = sort;
    }

    public Long getFixedFeeAmt() {
        return fixedFeeAmt;
    }

    public void setFixedFeeAmt(Long fixedFeeAmt) {
        this.fixedFeeAmt = fixedFeeAmt;
    }

    public Long getPayLimitAmt() {
        return payLimitAmt;
    }

    public void setPayLimitAmt(Long payLimitAmt) {
        this.payLimitAmt = payLimitAmt;
    }

    public String getFeeCalcType() {
        return feeCalcType;
    }

    public void setFeeCalcType(String feeCalcType) {
        this.feeCalcType = feeCalcType;
    }

    public String getFeeScaleType() {
        return feeScaleType;
    }

    public String getFeeTimeType() {
        return feeTimeType;
    }

    public void setFeeTimeType(String feeTimeType) {
        this.feeTimeType = feeTimeType;
    }

    public void setFeeScaleType(String feeScaleType) {
        this.feeScaleType = feeScaleType;
    }


    public String getFeeRate() {
        return feeRate;
    }

    public void setFeeRate(String feeRate) {
        this.feeRate = feeRate;
    }

    public String getFeeName() {
        return feeName;
    }

    public void setFeeName(String feeName) {
        this.feeName = feeName;
    }
}
