package com.abssqr.plat.common.model.convertor.web;

import com.abssqr.plat.common.dal.mysql.auto.paging.PlanListPage;
import com.abssqr.plat.common.facade.enums.*;
import com.abssqr.plat.common.facade.model.plan.FeeStructure;
import com.abssqr.plat.common.facade.model.plan.InvestStructure;
import com.abssqr.plat.common.facade.model.plan.Plan;
import com.abssqr.plat.common.facade.param.plan.PlanEditOprParam;
import com.abssqr.plat.common.facade.param.plan.PlanPageQryParam;
import com.abssqr.plat.common.facade.param.plan.sub.FeeStructureParam;
import com.abssqr.plat.common.facade.param.plan.sub.InvestStructureParam;
import com.abssqr.plat.common.facade.result.BasePage;
import com.abssqr.plat.common.facade.result.astPool.AstPoolVO;
import com.abssqr.plat.common.facade.result.plan.PlanVO;
import com.abssqr.plat.common.facade.result.plan.sub.FeeStructureVO;
import com.abssqr.plat.common.facade.result.plan.sub.InvestStructureVO;
import com.abssqr.plat.common.model.convertor.AstPoolConvert;
import com.abssqr.plat.common.model.convertor.PlanConvert;
import com.abssqr.plat.common.model.enums.IdTypeEnum;
import com.abssqr.plat.common.model.seq.SequenceUtil;
import org.apache.commons.collections.CollectionUtils;
import org.omg.CORBA.PUBLIC_MEMBER;

import java.util.ArrayList;
import java.util.List;

import java.math.BigDecimal;

public class PlanWebConvert {
    public static Plan convertPlanParam(PlanEditOprParam planEditOprParam){
        Plan plan=new Plan();
        //分配周期
        plan.setPayFreq(PlanPayFreqEnum.getByCode(planEditOprParam.getPayFreq()));
        plan.setBeginDate(planEditOprParam.getBeginDate());
        plan.setCalcIntrType(CalcIntrTypeEnum.getByCode(planEditOprParam.getCalcIntrType()));
        plan.setEndDate(planEditOprParam.getEndDate());
        plan.setFirstAllocDate(planEditOprParam.getFirstAllocDate());
        plan.setFirstCalcDate(planEditOprParam.getFirstCalcDate());
        plan.setFirstPayDate(planEditOprParam.getFirstPayDate());
        plan.setFirstReportDate(planEditOprParam.getFirstReportDate());
        plan.setFirstSettleDate(planEditOprParam.getFirstSettleDate());
        plan.setPlanFullName(planEditOprParam.getPlanFullName());
        plan.setTotalAmt(planEditOprParam.getTotalAmt());
        plan.setPlanName(planEditOprParam.getPlanName());
        plan.setPlanNo(planEditOprParam.getPlanNo());
        plan.setTradePlace(planEditOprParam.getTradePlace());

        if(CollectionUtils.isNotEmpty(planEditOprParam.getInvestStructureParam())) {
            for (InvestStructureParam investStructure : planEditOprParam.getInvestStructureParam()) {
                plan.getInvestStructure().add(convertInvestStructureParam(investStructure));
            }
        }
        if(CollectionUtils.isNotEmpty(planEditOprParam.getFeeStructureParam())){
            for(FeeStructureParam feeStructureParam:planEditOprParam.getFeeStructureParam()){
                plan.getFeeStructure().add(convertFeeStructure(feeStructureParam));
            }
        }

        return plan;
    }

    private static InvestStructure convertInvestStructureParam(InvestStructureParam investStructureParam){
        InvestStructure investStructure=new InvestStructure();
        investStructure.setEffectDate(investStructureParam.getEffectDate());
        investStructure.setEndDate(investStructureParam.getEndDate());
        investStructure.setExpectEndDate(investStructureParam.getExpectEndDate());
        investStructure.setGrade(investStructureParam.getGrade());
        investStructure.setIntrType(IntrTypeEnum.getByCode(investStructureParam.getIntrType()));
        investStructure.setAllocMethod(AllocMethodEnum.getByCode(investStructureParam.getAllocMethod()));

        investStructure.setSort(investStructureParam.getSort());
        investStructure.setLayerType(LayerTypeEnum.getByCode(investStructureParam.getLayerType()));
        investStructure.setLayerNo(SequenceUtil.genId(IdTypeEnum.INVESTSTRUCTURE));
        investStructure.setLayerName(investStructureParam.getLayerName());
        investStructure.setLayerIntr(new BigDecimal(investStructureParam.getLayerIntr()));
        investStructure.setLayerAmt(investStructureParam.getLayerAmt());

        return investStructure;
    }


    private static FeeStructure convertFeeStructure(FeeStructureParam feeStructureParam){
        FeeStructure feeStructure=new FeeStructure();
        feeStructure.setFeeTimeType(FeeTimeTypeEnum.getByCode(feeStructureParam.getFeeTimeType()));
        feeStructure.setPayLimitAmt(feeStructureParam.getPayLimitAmt());
        feeStructure.setSort(feeStructureParam.getSort());
        feeStructure.setFixedFeeAmt(feeStructureParam.getFixedFeeAmt());
        feeStructure.setFeeScaleType(FeeScaleTypeEnum.getByCode(feeStructureParam.getFeeScaleType()));
        feeStructure.setFeeRate(new BigDecimal(feeStructureParam.getFeeRate()));
        feeStructure.setFeeNo(SequenceUtil.genId(IdTypeEnum.FEE));
        feeStructure.setFeeCalcType(CalcTypeEnum.getByCode(feeStructureParam.getFeeCalcType()));

        feeStructure.setFeeName(feeStructureParam.getFeeName());
        return feeStructure;
    }

    public static PlanVO convert2PlanVO(Plan var){
        if(var==null){
            return null;
        }
        PlanVO result=new PlanVO();
        result.setPayFreq(var.getPayFreq());
        result.setBeginDate(var.getBeginDate());
        result.setCalcIntrType(var.getCalcIntrType());
        result.setEndDate(var.getEndDate());
        result.setFirstAllocDate(var.getFirstAllocDate());
        result.setFirstCalcDate(var.getFirstCalcDate());
        result.setFirstPayDate(var.getFirstPayDate());
        result.setFirstReportDate(var.getFirstReportDate());
        result.setFirstSettleDate(var.getFirstSettleDate());
        result.setPlanFullName(var.getPlanFullName());
        result.setTotalAmt(var.getTotalAmt());
        result.setPlanName(var.getPlanName());
        result.setPlanNo(var.getPlanNo());
        result.setStatus(var.getStatus());
        result.setTradePlace(var.getTradePlace());
        result.setGmtModifier(var.getGmtModifier());
        result.setGmtCreator(var.getGmtCreator());
        result.setInvestStructureList(convert2InvestStructureVOs(var.getInvestStructure()));
        result.setFeeStructureList(convert2FeeStructureVOs(var.getFeeStructure()));
        return result;
    }

    public static List<PlanVO> convert2PlanVOs(List<Plan> vars){
        if(vars==null){
            return null;
        }
        List<PlanVO> result=new ArrayList<>();
        vars.forEach(v->{
            result.add(convert2PlanVO(v));
        });
        return result;

    }

    private static FeeStructureVO convert2FeeStructureVO(FeeStructure var){
        if(var==null){
            return null;
        }
        FeeStructureVO result=new FeeStructureVO();
        result.setFeeTimeType(var.getFeeTimeType());
        result.setPlanNo(var.getPlanNo());
        result.setPayLimitAmt(var.getPayLimitAmt());
        result.setSort(var.getSort());
        result.setFixedFeeAmt(var.getFixedFeeAmt());
        result.setFeeScaleType(var.getFeeScaleType());
        result.setFeeRate(var.getFeeRate());
        result.setFeeNo(SequenceUtil.genId(IdTypeEnum.FEE));
        result.setFeeCalcType(var.getFeeCalcType());
        result.setFeeName(var.getFeeName());
        return result;
    }

    private static InvestStructureVO convertInvestStructureVO(InvestStructure var){
        if(var==null){
            return null;
        }
        InvestStructureVO result=new InvestStructureVO();

        result.setEffectDate(var.getEffectDate());
        result.setEndDate(var.getEndDate());
        result.setExpectEndDate(var.getExpectEndDate());
        result.setGrade(var.getGrade());
        result.setIntrType(var.getIntrType());
        result.setPlanNo(var.getPlanNo());
        result.setAllocMethod(var.getAllocMethod());

        result.setSort(var.getSort());
        result.setLayerType(var.getLayerType());
        result.setLayerNo(var.getLayerNo());
        result.setLayerName(var.getLayerName());
        result.setLayerIntr(var.getLayerIntr());
        result.setLayerAmt(var.getLayerAmt());
        return result;
    }
    private static List<FeeStructureVO> convert2FeeStructureVOs(List<FeeStructure> vars){
        if(vars==null){
            return null;
        }
        List<FeeStructureVO> result=new ArrayList<>();
        vars.forEach(v->{
            result.add(convert2FeeStructureVO(v));
        });
        return result;
    }

    private static List<InvestStructureVO> convert2InvestStructureVOs(List<InvestStructure> vars){
        if(vars==null){
            return null;
        }
        List<InvestStructureVO> result=new ArrayList<>();
        vars.forEach(v->{
            result.add(convertInvestStructureVO(v));
        });

        return result;
    }


    public static PlanListPage convertParam2Page(PlanPageQryParam planPageQryParam){
        PlanListPage planListPage=new PlanListPage();
        planListPage.setPlanName(planPageQryParam.getPlanName());
        planListPage.setStatus(planPageQryParam.getStatus());
        planListPage.setCurrPageNo(planPageQryParam.getPageNum());
        planListPage.setLimit(planPageQryParam.getPageSize());
        return planListPage;
    }

    public static BasePage<PlanVO> convertPage2VO(PlanListPage planListPage){
        BasePage<PlanVO> basePage=new BasePage<>();
        basePage.setDatas(PlanWebConvert.convert2PlanVOs(PlanConvert.convert2Entitys(planListPage.getDatas())));
        basePage.setLimit(planListPage.getLimit());
        basePage.setCurrPageNo(planListPage.getCurrPageNo());
        basePage.setTotal(planListPage.getTotal());
        return basePage;
    }

}
