package com.abssqr.plat.common.model.repo.plan.impl;

import com.abssqr.plat.common.dal.mysql.auto.dao.PlanAllocDAO;
import com.abssqr.plat.common.dal.mysql.auto.dao.PlanAllocItemDAO;
import com.abssqr.plat.common.dal.mysql.auto.dataobject.PlanAllocDO;
import com.abssqr.plat.common.facade.model.plan.PlanAlloc;
import com.abssqr.plat.common.facade.model.plan.PlanAllocItem;
import com.abssqr.plat.common.model.convertor.PlanAllocConvert;
import com.abssqr.plat.common.model.convertor.PlanAllocItemConvert;
import com.abssqr.plat.common.model.repo.plan.PlanAllocRepo;
import com.general.system.common.util.VarChecker;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;

@Component
public class PlanAllocRepoImpl implements PlanAllocRepo{

    @Autowired
    PlanAllocDAO planAllocDAO;

    @Autowired
    PlanAllocItemDAO planAllocItemDAO;


    @Override
    public List<PlanAlloc> queryByPlanNo(String planNo) {
        List<PlanAllocDO> planAllocDOList = planAllocDAO.getByPlanNo(planNo);
        return PlanAllocConvert.convert2Entitys(planAllocDOList);
    }

    @Override
    public void insertPlanAllocs(List<PlanAlloc> allocs) {
        int upct = planAllocDAO.insertBatch(PlanAllocConvert.convert2DOs(allocs));
        VarChecker.checkEquals(allocs.size(),upct,"更新数量不一致");

    }


    @Override
    public PlanAlloc getPlanAllocDetail(String allocNo) {
        PlanAllocDO planAllocDO = planAllocDAO.getByAllocNo(allocNo);
        return PlanAllocConvert.convert2Entity(planAllocDO);
    }

    @Override
    public void store(List<PlanAlloc> planAllocList) {
        if(CollectionUtils.isNotEmpty(planAllocList)){
            int upct = planAllocDAO.insertBatch(PlanAllocConvert.convert2DOs(planAllocList));
            VarChecker.checkEquals(planAllocList.size(),upct,"更新数量不一致");
            List<PlanAllocItem> planAllocItems=new ArrayList<>();
            planAllocList.forEach(v->{
                if(CollectionUtils.isNotEmpty(v.getPlanAllocItems())){
                    planAllocItems.addAll(v.getPlanAllocItems());
                }
            });
            if(CollectionUtils.isNotEmpty(planAllocItems)){
                int upct2 = planAllocItemDAO.insertBatch(PlanAllocItemConvert.convert2DOs(planAllocItems));
                VarChecker.checkEquals(planAllocItems.size(),upct2,"更新数量不一致");
            }
        }

    }

    @Override
    public void cleanByPlanNo(String planNo) {
        planAllocDAO.deleteByPlanNo(planNo);
        planAllocItemDAO.deleteByPlanNo(planNo);
    }
}
