package com.abssqr.plat.core.service.plan;

import com.abssqr.plat.common.facade.enums.LayerTypeEnum;
import com.abssqr.plat.common.facade.enums.PlanStatusEnum;
import com.abssqr.plat.common.facade.enums.TitleTypeEnum;
import com.abssqr.plat.common.facade.model.plan.FeeStructure;
import com.abssqr.plat.common.facade.model.plan.InvestStructure;
import com.abssqr.plat.common.facade.model.plan.PlanAcctTitle;
import com.abssqr.plat.common.facade.model.plan.PlanBase;
import com.abssqr.plat.common.model.enums.IdTypeEnum;
import com.abssqr.plat.common.model.repo.plan.PlanAcctTitleRepo;
import com.abssqr.plat.common.model.seq.SequenceUtil;
import com.general.system.common.util.MessageUtil;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;

/**
 * 科目信息
 */
@Component
public class PlanAccTitleManager {

    @Autowired
    PlanAcctTitleRepo planAcctTitleRepo;

    /**
     * 初始化科目信息
     * @param investStructureList
     * @param feeStructureList
     */
    public void initAccTitles(PlanStatusEnum planStatus,String planNo, List<InvestStructure> investStructureList,
                            List<FeeStructure> feeStructureList){

        List<PlanAcctTitle> planAcctTitleList=new ArrayList<>();
        if(planStatus== PlanStatusEnum.PREPARING){
            planAcctTitleRepo.cleanByPlanNo(planNo);
        }
        //根据投资结构生成科目
        if(CollectionUtils.isNotEmpty(investStructureList)){
            for(InvestStructure investStructure:investStructureList){
                buildFromInvestStructure(planNo,planAcctTitleList,investStructure);
            }
        }

        //根据费用结构生成科目
        if(CollectionUtils.isNotEmpty(feeStructureList)){
            for(FeeStructure feeStructure:feeStructureList){
                buildFromFeeStructure(planNo,planAcctTitleList,feeStructure);
            }
        }
        planAcctTitleRepo.insertBatch(planAcctTitleList);
    }

    /**
     * 根据投资结构生成科目
     * @param planNo
     * @param planAcctTitleList
     * @param investStructure
     */
    private void buildFromInvestStructure(String planNo,List<PlanAcctTitle> planAcctTitleList,InvestStructure investStructure){
        PlanAcctTitle investAccTitle = this.buildBasicTitle(planNo);

        TitleTypeEnum titleType = (investStructure.getLayerType() == LayerTypeEnum.PRIOR) ?
                TitleTypeEnum.PRIOR_INVESTED :
                TitleTypeEnum.SECND_INVESTED;

        investAccTitle.setTitleType(titleType);
        investAccTitle.setTitleName(MessageUtil.formatMsg("{0}-{1}",
                StringUtils.trim(investStructure.getLayerName()), TitleTypeEnum.INVESTED.getDesc()));
        investAccTitle.setRefNo(investStructure.getLayerNo());

        planAcctTitleList.add(investAccTitle);

        PlanAcctTitle intrAccTitle=buildBasicTitle(planNo);
        intrAccTitle.setTitleName(MessageUtil.formatMsg("{0}-{1}",
                StringUtils.trim(investStructure.getLayerName()), TitleTypeEnum.INVEST_PROFIT.getDesc()));

        intrAccTitle.setTitleType(TitleTypeEnum.INVEST_PROFIT);
        intrAccTitle.setRefNo(investStructure.getLayerNo());

        planAcctTitleList.add(intrAccTitle);
    }

    /**
     * 根据费用结构生成科目
     * @param planNo
     * @param planAcctTitleList
     * @param feeStructure
     */
    private void buildFromFeeStructure(String planNo,List<PlanAcctTitle> planAcctTitleList,FeeStructure feeStructure){
        PlanAcctTitle feeTitle = this.buildBasicTitle(planNo);

        feeTitle.setTitleName(feeStructure.getFeeName());
        feeTitle.setRefNo(feeStructure.getFeeNo());
        feeTitle.setTitleType(TitleTypeEnum.FEE);

        planAcctTitleList.add(feeTitle);
    }

    public  PlanAcctTitle buildBasicTitle(String planNo){
        PlanAcctTitle planAcctTitle = new PlanAcctTitle();
        planAcctTitle.setPlanNo(planNo);
        planAcctTitle.setTitleNo(SequenceUtil.genId(IdTypeEnum.ACCT_TITLE_CODE));
        return planAcctTitle;
    }
}
