package com.abssqr.plat.core.service.plan;

import com.abssqr.plat.common.dal.mysql.auto.paging.PlanListPage;
import com.abssqr.plat.common.facade.enums.PlanStatusEnum;
import com.abssqr.plat.common.facade.model.plan.*;
import com.abssqr.plat.common.facade.param.plan.PlanEditOprParam;
import com.abssqr.plat.common.facade.param.plan.sub.InvestStructureParam;
import com.abssqr.plat.common.facade.result.BasePage;
import com.abssqr.plat.common.facade.result.plan.PlanVO;
import com.abssqr.plat.common.model.convertor.web.PlanWebConvert;
import com.abssqr.plat.common.model.enums.IdTypeEnum;
import com.abssqr.plat.common.model.repo.plan.PlanAcctTitleRepo;
import com.abssqr.plat.common.model.repo.plan.PlanFeeStructureRepo;
import com.abssqr.plat.common.model.repo.plan.PlanInvestStructureRepo;
import com.abssqr.plat.common.model.repo.plan.PlanRepo;
import com.abssqr.plat.common.model.seq.SequenceUtil;
import com.abssqr.plat.core.service.accounting.OrgAcctDayComponent;
import com.general.system.common.util.DateTimeUtil;
import com.general.system.common.util.VarChecker;
import com.general.system.facade.current.IdentityUtil;
import org.apache.commons.collections.CollectionUtils;
import org.aspectj.weaver.ast.Var;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;

/**
 * 计划管理
 */
@Component
public class PlanMananger {
    @Autowired
    PlanRepo planRepo;

    @Autowired
    PlanInvestStructureRepo investStructureRepo;

    @Autowired
    PlanFeeStructureRepo  feeStructureRepo;

    @Autowired
    PlanAcctTitleRepo planAcctTitleRepo;

    @Autowired
    PlanAccTitleManager planAccTitleManager;

    @Autowired
    PlanAllocManager planAllocManager;

    @Autowired
    OrgAcctDayComponent orgAcctDayComponent;

    public String addOrUpdatePlan(PlanEditOprParam planEditOprParam,String userCode){

        Plan plan = PlanWebConvert.convertPlanParam(planEditOprParam);

        List<InvestStructure> investStructureList = plan.getInvestStructure();

        List<FeeStructure> feeStructureList = plan.getFeeStructure();

        //校验参数
        checkParam(planEditOprParam);

        PlanBase existPlan=null;
        if(planEditOprParam.getPlanNo()!=null){
            existPlan = planRepo.getPlanByNo(planEditOprParam.getPlanNo());
            VarChecker.checkArgument(existPlan.getStatus()==PlanStatusEnum.DRAFT,"产品[{0}]不存在"
                    ,existPlan.getPlanFullName());
        }else{
            plan.setPlanNo(SequenceUtil.genId(IdTypeEnum.ABS_PLAN));
            plan.setGmtCreator(IdentityUtil.getUserOrgCode());
            plan.setGmtModifier(IdentityUtil.getUserCode());
        }
        //如果是暂存
        if(planEditOprParam.isDraft()){
            //判断计划是否存在
            if(existPlan!=null){
                VarChecker.checkArgument(existPlan.getStatus()==PlanStatusEnum.DRAFT,"产品[{0}]状态不为暂存不能暂存"
                        ,existPlan.getPlanFullName());
            }
            //如果是新增则生成产品编号，且将产品状态置为暂存
            if(planEditOprParam.getPlanNo()==null){
                plan.setStatus(PlanStatusEnum.DRAFT);
            }

        }else{
            plan.setStatus(PlanStatusEnum.PREPARING);
            //初始化科目信息
            planAccTitleManager.initAccTitles(PlanStatusEnum.PREPARING,plan.getPlanNo(),plan.getInvestStructure(),plan.getFeeStructure());
            //初始化分配计划
            planAllocManager.initPlanAlloc(plan,PlanStatusEnum.PREPARING);
        }
        //更新/新增产品，投资结构，费用结构
        if(planEditOprParam.getPlanNo()==null){
            planRepo.addPlan(plan);
        }else{
            plan.setGmtModifier(IdentityUtil.getUserOrgCode());
            planRepo.updatePlan(plan);
            investStructureRepo.cleanByPlanNo(plan.getPlanNo());
            feeStructureRepo.cleanByPlanNo(plan.getPlanNo());
        }
        investStructureRepo.add(plan.getPlanNo(),investStructureList);
        feeStructureRepo.add(plan.getPlanNo(),feeStructureList);

        return plan.getPlanNo();
    }




    /**
     * 判断参数：
     * 判断条件：
     * 1，产品到期日>首次结息日，首次分配日，首次转付日，首次报告日>首次计算日
     * 2，首次分配日>首次结息日
     * 3, 投资机构和起息日>当前日期，且计划到期日<项目到期日,投资结构起息日<投资结构到期日
     *
     * @param param
     */
    private void checkParam(PlanEditOprParam param){
        //判断产品简称/全称是否存在
        VarChecker.checkArgument(!planRepo.planExist(param.getPlanFullName(), param.getPlanName()), "存在该[{0}]产品全称[{1}]产品简称",param.getPlanFullName(),param.getPlanName());


        Date sysDate = orgAcctDayComponent.getTrfAcctDay().getStandardDate();

        Date endDate = param.getEndDate();
        Date firstAllocDate = param.getFirstAllocDate();
        Date firstCalcDate = param.getFirstCalcDate();
        Date firstPayDate = param.getFirstPayDate();
        Date firstReportDate = param.getFirstReportDate();
        Date firstSettleDate = param.getFirstSettleDate();

        VarChecker.checkArgument(DateTimeUtil.between(firstAllocDate,firstCalcDate,endDate, DateTimeUtil.BetweenType.s),"首次首次分配日应小于到期日 大于计算日");
        VarChecker.checkArgument(DateTimeUtil.between(firstSettleDate,firstCalcDate,endDate, DateTimeUtil.BetweenType.s),"首次结息日应小于到期日 大于计算日");
        VarChecker.checkArgument(DateTimeUtil.between(firstPayDate,firstCalcDate,endDate, DateTimeUtil.BetweenType.s),"首次转付日应小于到期日 大于计算日");
        VarChecker.checkArgument(DateTimeUtil.between(firstReportDate,firstCalcDate,endDate, DateTimeUtil.BetweenType.s),"首次报告日应小于到期日 大于计算日");
        VarChecker.checkArgument(DateTimeUtil.between(firstAllocDate,firstSettleDate,endDate, DateTimeUtil.BetweenType.s),"首次分配日应大于首次结息日");
        List<InvestStructureParam> investStructureParamList = param.getInvestStructureParam();

        //遍历所有的投资结构判断其起息日和到期日
        if(CollectionUtils.isNotEmpty(investStructureParamList)){
            for(InvestStructureParam investStructure:investStructureParamList){
                //起息日大于当前日期
                VarChecker.checkArgument(DateTimeUtil.isBeforeOnDate(sysDate,investStructure.getEffectDate()),"投资结构[{0}]起息日[{1}]不能小于系统日期[{2}]",investStructure.getLayerName(),investStructure.getEffectDate(),sysDate);
                //投资结构结束日大于计划结束日
                VarChecker.checkArgument(DateTimeUtil.isBeforeOnDate(investStructure.getEndDate(),param.getEndDate()),"投资结构[{0}]到期日[{1}]应小于计划到期日[{2}]",investStructure.getLayerName(),investStructure.getEndDate(),param.getEndDate());
                VarChecker.checkArgument(DateTimeUtil.isBeforeOnDate(investStructure.getEffectDate(),investStructure.getEndDate()),"投资结构[{0}]起息日[{1}]应小于到期日[{2}]",investStructure.getLayerName(),investStructure.getEffectDate(),investStructure.getEndDate());
            }

        }
    }

    public Plan getPlan(String planNo){
        Plan plan = planRepo.getPlanByNo(planNo);
        List<InvestStructure> investStructures = investStructureRepo.selectByPlanNo(planNo);
        if(CollectionUtils.isNotEmpty(investStructures)){
            plan.getInvestStructure().addAll(investStructures);
        }
        List<FeeStructure> feeStructures = feeStructureRepo.selectByPlanNo(planNo);
        if(CollectionUtils.isNotEmpty(feeStructures)){
            plan.getFeeStructure().addAll(feeStructures);
        }
        return plan;
    }



}
